# shellfit
A function fitting code utilizing shell-style history. 
Press up to get your last fit result as the new fit input. 
 
 Author: dr Andrii Shyichuk, University of Wrocław, 
 email: andrii.shyichuk@uwr.edu.pl 

  This code is distributed under a Source-Available license.
  Commercial use requires a separate license. Contact me for details.


Copyright (c) 2025 Andrii Shyichuk. All rights reserved.


Shellfit has no dedicated paper yet. 
Cite this for now: https://www.frontiersin.org/journals/chemistry/articles/10.3389/fchem.2025.1501039/full


Use as: shellfit file --option value
The file must be a multy-column white-space separated data.
Type shellfit -h or shellfit --help for help.
Type shellfit -hf or shellfit --funcs fot function details.
